@@ -1,6 +1,7 @@
 """
 In this example, I'm going to show you how easy it is to integrate the gui into
-your already made game.
+your already made game. Also demonstrates linking custom functions (very cool,
+be sure to see)!
 """
 
 import sys
@@ -19,22 +20,32 @@ screen = pygame.display.set_mode((640, 480))
 # to use. This way, it won't set the display.
 gui.init(myscreen=screen)
 
-# We create our app...
-app = gui.App()
-data = "This example is for demonstrating how you can easily use GooeyPy in your already made game."
-tb = gui.TextBlock(value=data, x=100, y=20, width=350)
-app.add(tb)
+app = gui.App(width=640, height=100)
+
 
 # Lets create a very simple game where you move around an image.
 image = gui.get_image("image.png")
 x = 200
 y = 250
-movedir = {
-    "right":False,
-    "left":False,
-    "up":False,
-    "down":False,
-}
+
+
+tb = gui.TextBlock(value="This example is for demonstrating how you can easily use GooeyPy in your already made game.", align="center", y=20, width=350)
+
+
+def get_data():
+    # We are going to set this function to be the value of the TextBlock widget,
+    # (i.e. link it). Because GooeyPy doesn't know when x or y changes, it will
+    # call this function every tick. It will still only update it's widgets when
+    # it has to though. :)
+    return "Current pie position: %s, %s" % (x,y)
+# Remeber that when you pass a function as a value to pass a refrence of the
+# function and not call it (as that would assign the vaues, not the actual
+# function). This works not only with the value field but with all the
+# styling options as well, such as x, y, width, height and the list goes on...
+# see docs for full list of style options.
+l = gui.Label(get_data, align="center", y=70, font_size=25, color=(255,255,255))
+
+app.add(tb, l)
 
 while True:
     clock.tick(40)
@@ -46,39 +57,24 @@ while True:
             sys.exit()
 
         elif event.type == KEYDOWN:
-            if event.key == K_RIGHT:
-                movedir["right"] = True
-            elif event.key == K_LEFT:
-                movedir["left"] = True
-            elif event.key == K_UP:
-                movedir["up"] = True
-            elif event.key == K_DOWN:
-                movedir["down"] = True
+            if event.key == K_ESCAPE:
+                sys.exit()
 
-        elif event.type == KEYUP:
-            if event.key == K_RIGHT:
-                movedir["right"] = False
-            elif event.key == K_LEFT:
-                movedir["left"] = False
-            elif event.key == K_UP:
-                movedir["up"] = False
-            elif event.key == K_DOWN:
-                movedir["down"] = False
-
-    if movedir["right"]:
+    k = pygame.key.get_pressed()
+    if k[K_RIGHT]:
         x += 5
-    if movedir["left"]:
+    if k[K_LEFT]:
         x -= 5
-    if movedir["down"]:
+    if k[K_DOWN]:
         y += 5
-    if movedir["up"]:
+    if k[K_UP]:
         y -= 5
     x = max(0, min(x, 460))
     y = max(100, min(y, 360))
 
     app.run(events)
 
-    # In the event of wanting the gui to be drawn to the screen every time, you
+    # If you want the gui to be drawn to the screen every time, you
     # can set "app.dirty = True" before calling app.draw()
     app.draw()
 
@@ -96,9 +92,10 @@ while True:
     myupdaterects.append(dirty_rect)
 
     # Now we update the screen!
-    myupdaterects.extend(gui.update_rects)
     pygame.display.update(myupdaterects)
 
-    # Don't forget to clear the dirty rect lists!
+    # Don't forget to clear the dirty rect list!
     myupdaterects = []
-    gui.update_rects = []
\ No newline at end of file
+
+    # Then we update the rects for the gui.
+    gui.update_display()
\ No newline at end of file
