@@ -6,7 +6,7 @@ import sys
 sys.path.insert(0, "..")
 
 import pygame
-import gooeypy as gui
+from gooeypy import sdl as gui
 from gooeypy.const import *
 
 # Ok, this is really really cool... a CLOCK!!! Ok, so maybe that's not so new...
@@ -52,21 +52,21 @@ b1.connect(CLICK, menus.activate, 1)
 b2 = gui.Button("menu2")
 b2.connect(CLICK, menus.activate, 2)
 menubar = gui.HBox(align="center", valign="bottom", y=-20, spacing=20)
-menubar.add([b1, b2])
+menubar.add(b1, b2)
 data = "This example shows a cool way of handling a main menu system, which tends to be a rather common thing that most games do."
 tb = gui.TextBlock(value=data, align="center", y=20, width=400)
-mainmenu.add([menubar, tb])
+mainmenu.add(menubar, tb)
 
 menu1 = gui.Container(width=640, height=480)
 w1 = gui.Input(align="center", valign="center")
-menu1.add([back_button, w1])
+menu1.add(back_button, w1)
 
 menu2 = gui.Container(width=640, height=480)
 w2 = gui.Button("I do nada!", align="center", valign="center")
-menu2.add([back_button, w2])
+menu2.add(back_button, w2)
 
 # Now we add our menus to... menus!
-menus.add([mainmenu, menu1, menu2])
+menus.add(mainmenu, menu1, menu2)
 
 # And active the mainmenu.
 menus.activate(0)
