@@ -8,6 +8,7 @@ except NameError:
     from sets import Set as set # Python 2.3 fallback
 
 from cellulose import *
+from cellulose.extra.restrictions import *
 
 screen = None
 screen_width = 0
@@ -16,7 +17,7 @@ screen_height = 0
 
 custom_cells = set()
 
-class ReplaceableCellDescriptor(InputCellDescriptor):
+class ReplaceableCellDescriptor(RestrictedInputCellDescriptor):
 
     def __set__(self, obj, value):
         from widget import Widget
@@ -33,7 +34,7 @@ class ReplaceableCellDescriptor(InputCellDescriptor):
                 #obj._cells = {}
             #obj._cells[self.get_name(obj.__class__)] = value._cells['value']
         else:
-            self.get_cell(obj, value).set(value)
+            self.get_cell(obj).set(value)
 
 widgets = None
 
